#include "G4RunManager.hh"         // toolkit classes
#include "G4UImanager.hh"          //

#include "anti01DetectorConstruction.hh"
//#include "anti01PhysicsList.hh"
#include "FTFP_BERT.hh"
#include "anti01ActionInitialization.hh"

#include "G4UImanager.hh"
#include "G4UIcommand.hh" 
#include "G4VisExecutive.hh"
#include "G4UIExecutive.hh"


int main(int argc, char* argv[])
{
  // construct the default run manager
  G4RunManager* runManager = new G4RunManager;
  
  int evNum = 1; 
  if (argc==2) evNum=atoi(argv[1]);

  
  // set mandatory initialization classes
  anti01DetectorConstruction* detConstruction = new anti01DetectorConstruction();
  runManager->SetUserInitialization(detConstruction);

  G4VModularPhysicsList* physicsList = new FTFP_BERT;
  runManager->SetUserInitialization(physicsList);

  runManager->SetUserInitialization(new anti01ActionInitialization(detConstruction));

  // initialize G4 kernel
  runManager->Initialize();

  // get the pointer to the UI manager and set verbosities

  G4VisManager* visManager = new G4VisExecutive;                                                                                                
  visManager->Initialize();

  G4UImanager* UImanager = G4UImanager::GetUIpointer();
//
// UImanager->ApplyCommand("/run/verbose 1");
// UImanager->ApplyCommand("/event/verbose 1");
// UImanager->ApplyCommand("/tracking/verbose 1");

  // start a run
  if (argc==2) {                                                                                                                                
    // batch mode
   runManager->Initialize();
   runManager->BeamOn(evNum);
  }
  else if (argc==1){ 
    // interactive mode
    G4UIExecutive* ui = new G4UIExecutive(argc, argv);
    UImanager->ApplyCommand("/run/initialize"); 
    UImanager->ApplyCommand("/control/execute vis.mac"); 
    ui->SessionStart();
    delete ui;
  }

  // job termination
  delete runManager;
  delete visManager;
  return 0;
}
